@@ -9,14 +9,14 @@ from datetime import datetime, timedelta
 from cachecontrol import CacheControl
 from collections import deque
 
-__version__ = "0.12"
+__version__ = "0.13"
 
 __LONG_SCALE__ = float(0xFFFFFFFFFFFFFFF)
 
 class Config(object):
 
     def __init__(self, base_uri, connect_timeout = 2, read_timeout = 10):
-        self._base_uri = base_uri
+        self._base_uri = base_uri.rstrip('\\')
         self._connect = connect_timeout
         self._read = read_timeout
 
@@ -141,6 +141,7 @@ def _param_for_user(feature, user):
     if 'key' in user and user['key']:
         idHash = user['key']
     else:
+        logging.exception('User does not have a valid key set. Returning default value for flag.')
         return None
     if 'secondary' in user:
         idHash += "." + user['secondary']
